@@ -41,6 +41,9 @@ def fit_font(font_name, max_height):
             end = k
         else:
             start = k + 1
+        if start < end:
+            # Run garbadge collector, to avoid opening too many files
+            del font
 
     return font
 
